@@ -51,6 +51,9 @@
 //!
 //! ### TLS
 //!
+//! **Note**: not enabling any TLS feature is support for use behind a proxy;
+//! Discord's API is HTTPS only.
+//!
 //! `twilight-gateway` has features to enable [`tokio-tungstenite`] and
 //! [`twilight-http`]'s TLS features. These features are mutually exclusive.
 //! `rustls-native-roots` is enabled by default.
@@ -176,12 +179,3 @@ pub use twilight_model::gateway::event::{Event, EventType};
 
 /// Discord API version used by this crate.
 pub const API_VERSION: u8 = 10;
-
-#[cfg(not(any(
-    feature = "native",
-    feature = "rustls-native-roots",
-    feature = "rustls-webpki-roots"
-)))]
-compile_error!(
-    "Either the `native`, `rustls-native-roots` or `rustls-webpki-roots` feature must be enabled."
-);
